==> ibiz-model-8.1.0.317-sources.jar: net/ibizsys/model/app/msg/PSAppMsgTemplImpl.java <==
package net.ibizsys.model.app.msg;



public class PSAppMsgTemplImpl extends net.ibizsys.model.app.PSApplicationObjectImpl implements net.ibizsys.model.app.msg.IPSAppMsgTempl{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETCONTENT = "content";
	public final static String ATTR_GETCONTENTPSLANGUAGERES = "getContentPSLanguageRes";
	public final static String ATTR_GETCONTENTTYPE = "contentType";
	public final static String ATTR_GETDDCONTENT = "dDContent";
	public final static String ATTR_GETDDPSLANGUAGERES = "getDDPSLanguageRes";
	public final static String ATTR_GETDYNAMODELFILEPATH = "dynaModelFilePath";
	public final static String ATTR_GETIMCONTENT = "iMContent";
	public final static String ATTR_GETIMPSLANGUAGERES = "getIMPSLanguageRes";
	public final static String ATTR_GETMOBTASKURL = "mobTaskUrl";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETPSSYSTEMMODULE = "getPSSystemModule";
	public final static String ATTR_GETSMSCONTENT = "sMSContent";
	public final static String ATTR_GETSMSPSLANGUAGERES = "getSMSPSLanguageRes";
	public final static String ATTR_GETSUBPSLANGUAGERES = "getSubPSLanguageRes";
	public final static String ATTR_GETSUBJECT = "subject";
	public final static String ATTR_GETTASKURL = "taskUrl";
	public final static String ATTR_GETWXCONTENT = "wXContent";
	public final static String ATTR_GETWXPSLANGUAGERES = "getWXPSLanguageRes";
	public final static String ATTR_ISMAILGROUPSEND = "mailGroupSend";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes contentpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageRes(){
		if(this.contentpslanguageres != null) return this.contentpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.contentpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCONTENTPSLANGUAGERES);
		return this.contentpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getContentPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定内容多语言资源对象");}
		return value;
	}


	public java.lang.String getContentType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTTYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getDDContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDDCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes ddpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getDDPSLanguageRes(){
		if(this.ddpslanguageres != null) return this.ddpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDDPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.ddpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETDDPSLANGUAGERES);
		return this.ddpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getDDPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getDDPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定钉钉内容多语言资源对象");}
		return value;
	}


	@Deprecated
	public java.lang.String getDynaModelFilePath(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMODELFILEPATH);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getIMContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETIMCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes impslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getIMPSLanguageRes(){
		if(this.impslanguageres != null) return this.impslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETIMPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.impslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETIMPSLANGUAGERES);
		return this.impslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getIMPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getIMPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定即时消息多语言资源对象");}
		return value;
	}


	public java.lang.String getMobTaskUrl(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMOBTASKURL);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	@Deprecated
	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}
	private net.ibizsys.model.system.IPSSystemModule pssystemmodule;

	public net.ibizsys.model.system.IPSSystemModule getPSSystemModule(){
		if(this.pssystemmodule != null) return this.pssystemmodule;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSSYSTEMMODULE);
		if(value == null){
			return null;
		}
		this.pssystemmodule = getPSModelObject(net.ibizsys.model.system.IPSSystemModule.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETPSSYSTEMMODULE);
		return this.pssystemmodule;
	}

	public net.ibizsys.model.system.IPSSystemModule getPSSystemModuleMust(){
		net.ibizsys.model.system.IPSSystemModule value = this.getPSSystemModule();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定系统模块");}
		return value;
	}


	public java.lang.String getSMSContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSMSCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes smspslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getSMSPSLanguageRes(){
		if(this.smspslanguageres != null) return this.smspslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSMSPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.smspslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETSMSPSLANGUAGERES);
		return this.smspslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getSMSPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getSMSPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定短消息多语言资源对象");}
		return value;
	}

	private net.ibizsys.model.res.IPSLanguageRes subpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getSubPSLanguageRes(){
		if(this.subpslanguageres != null) return this.subpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSUBPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.subpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETSUBPSLANGUAGERES);
		return this.subpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getSubPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getSubPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定标题多语言资源对象");}
		return value;
	}


	public java.lang.String getSubject(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSUBJECT);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getTaskUrl(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTASKURL);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getWXContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETWXCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes wxpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getWXPSLanguageRes(){
		if(this.wxpslanguageres != null) return this.wxpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETWXPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.wxpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETWXPSLANGUAGERES);
		return this.wxpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getWXPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getWXPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定微信内容多语言资源对象");}
		return value;
	}


	public boolean isMailGroupSend(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISMAILGROUPSEND);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}

==> ibiz-model-8.1.0.465-sources.jar: net/ibizsys/model/app/msg/PSAppMsgTemplImpl.java <==
package net.ibizsys.model.app.msg;



public class PSAppMsgTemplImpl extends net.ibizsys.model.app.PSApplicationObjectImpl implements net.ibizsys.model.app.msg.IPSAppMsgTempl{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETCONTENT = "content";
	public final static String ATTR_GETCONTENTPSLANGUAGERES = "getContentPSLanguageRes";
	public final static String ATTR_GETCONTENTTYPE = "contentType";
	public final static String ATTR_GETDDCONTENT = "dDContent";
	public final static String ATTR_GETDDPSLANGUAGERES = "getDDPSLanguageRes";
	public final static String ATTR_GETDYNAMODELFILEPATH = "dynaModelFilePath";
	public final static String ATTR_GETIMCONTENT = "iMContent";
	public final static String ATTR_GETIMPSLANGUAGERES = "getIMPSLanguageRes";
	public final static String ATTR_GETMOBTASKURL = "mobTaskUrl";
	public final static String ATTR_GETMSGTEMPLPARAMS = "msgTemplParams";
	public final static String ATTR_GETMSGTEMPLTAG = "msgTemplTag";
	public final static String ATTR_GETMSGTEMPLTAG2 = "msgTemplTag2";
	public final static String ATTR_GETMSGTEMPLTYPE = "msgTemplType";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETPSSYSSFPLUGIN = "getPSSysSFPlugin";
	public final static String ATTR_GETPSSYSTEMMODULE = "getPSSystemModule";
	public final static String ATTR_GETSMSCONTENT = "sMSContent";
	public final static String ATTR_GETSMSPSLANGUAGERES = "getSMSPSLanguageRes";
	public final static String ATTR_GETSCRIPTCODE = "scriptCode";
	public final static String ATTR_GETSCRIPTMODE = "scriptMode";
	public final static String ATTR_GETSUBPSLANGUAGERES = "getSubPSLanguageRes";
	public final static String ATTR_GETSUBJECT = "subject";
	public final static String ATTR_GETTASKURL = "taskUrl";
	public final static String ATTR_GETTEMPLENGINE = "templEngine";
	public final static String ATTR_GETWXCONTENT = "wXContent";
	public final static String ATTR_GETWXPSLANGUAGERES = "getWXPSLanguageRes";
	public final static String ATTR_ISMAILGROUPSEND = "mailGroupSend";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes contentpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageRes(){
		if(this.contentpslanguageres != null) return this.contentpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.contentpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCONTENTPSLANGUAGERES);
		return this.contentpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getContentPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定内容多语言资源对象");}
		return value;
	}


	public java.lang.String getContentType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTTYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getDDContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDDCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes ddpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getDDPSLanguageRes(){
		if(this.ddpslanguageres != null) return this.ddpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDDPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.ddpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETDDPSLANGUAGERES);
		return this.ddpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getDDPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getDDPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定钉钉内容多语言资源对象");}
		return value;
	}


	@Deprecated
	public java.lang.String getDynaModelFilePath(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMODELFILEPATH);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getIMContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETIMCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes impslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getIMPSLanguageRes(){
		if(this.impslanguageres != null) return this.impslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETIMPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.impslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETIMPSLANGUAGERES);
		return this.impslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getIMPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getIMPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定即时消息多语言资源对象");}
		return value;
	}


	public java.lang.String getMobTaskUrl(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMOBTASKURL);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	@Deprecated
	public com.fasterxml.jackson.databind.node.ObjectNode getMsgTemplParams(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMSGTEMPLPARAMS);
		if(value == null){
			return null;
		}
		return (com.fasterxml.jackson.databind.node.ObjectNode)value;
	}

	public java.lang.String getMsgTemplTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMSGTEMPLTAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMsgTemplTag2(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMSGTEMPLTAG2);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMsgTemplType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMSGTEMPLTYPE);
		if(value == null){
			return "STATIC";
		}
		return value.asText();
	}

	@Deprecated
	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}
	private net.ibizsys.model.res.IPSSysSFPlugin pssyssfplugin;

	@Deprecated
	public net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPlugin(){
		if(this.pssyssfplugin != null) return this.pssyssfplugin;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSSYSSFPLUGIN);
		if(value == null){
			return null;
		}
		this.pssyssfplugin = getPSModelObject(net.ibizsys.model.res.IPSSysSFPlugin.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETPSSYSSFPLUGIN);
		return this.pssyssfplugin;
	}

	public net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPluginMust(){
		net.ibizsys.model.res.IPSSysSFPlugin value = this.getPSSysSFPlugin();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "[getPSSysSFPlugin]返回空值");}
		return value;
	}

	private net.ibizsys.model.system.IPSSystemModule pssystemmodule;

	public net.ibizsys.model.system.IPSSystemModule getPSSystemModule(){
		if(this.pssystemmodule != null) return this.pssystemmodule;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSSYSTEMMODULE);
		if(value == null){
			return null;
		}
		this.pssystemmodule = getPSModelObject(net.ibizsys.model.system.IPSSystemModule.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETPSSYSTEMMODULE);
		return this.pssystemmodule;
	}

	public net.ibizsys.model.system.IPSSystemModule getPSSystemModuleMust(){
		net.ibizsys.model.system.IPSSystemModule value = this.getPSSystemModule();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定系统模块");}
		return value;
	}


	public java.lang.String getSMSContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSMSCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes smspslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getSMSPSLanguageRes(){
		if(this.smspslanguageres != null) return this.smspslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSMSPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.smspslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETSMSPSLANGUAGERES);
		return this.smspslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getSMSPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getSMSPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定短消息多语言资源对象");}
		return value;
	}


	public java.lang.String getScriptCode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSCRIPTCODE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getScriptMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSCRIPTMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}
	private net.ibizsys.model.res.IPSLanguageRes subpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getSubPSLanguageRes(){
		if(this.subpslanguageres != null) return this.subpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSUBPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.subpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETSUBPSLANGUAGERES);
		return this.subpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getSubPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getSubPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定标题多语言资源对象");}
		return value;
	}


	public java.lang.String getSubject(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSUBJECT);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getTaskUrl(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTASKURL);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getTemplEngine(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTEMPLENGINE);
		if(value == null){
			return "FREEMARKER";
		}
		return value.asText();
	}

	public java.lang.String getWXContent(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETWXCONTENT);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes wxpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getWXPSLanguageRes(){
		if(this.wxpslanguageres != null) return this.wxpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETWXPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.wxpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETWXPSLANGUAGERES);
		return this.wxpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getWXPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getWXPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定微信内容多语言资源对象");}
		return value;
	}


	public boolean isMailGroupSend(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISMAILGROUPSEND);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}
